#!/usr/bin/php
<?php

/**
 * @var Site zip file
 */
if ($argc < 2) {
	echo "Usage: php site2dropin <site_file> [<dropin_dir>] [<arch>]\n";
	exit(1);
}
$site_file = $argv[1];
if (array_key_exists(2,$argv))
	$tmp_dir = $argv[2];
else
	$tmp_dir = "./tmp";

if (array_key_exists(3,$argv)) {
	switch ($argv[3]) {
		case 'i386':
			$arch = 'x86';
			break;
		case 'amd64':
			$arch = 'x86_64';
			break;
		case 'powerpc':
			$arch = 'ppc';
			break;
		default:
			$arch = $argv[3];
	}
} else {
	$arch = "x86";
}

$target_dir = "$tmp_dir/eclipse";

echo "Cleaning up...\n";
if (file_exists($tmp_dir))
	exec("rm -r $tmp_dir");
mkdir($tmp_dir);
mkdir($target_dir);
mkdir("$target_dir/features");
mkdir("$target_dir/plugins");

if (is_file($site_file)) {
	$site_dir = "$tmp_dir/site";
	$site_zip = new ZipArchive();
	if ($site_zip->open($site_file) !== true) {
		echo "Unable to open .zip file\n";
		exit(1);
	}
	$site_zip->extractTo($site_dir);
	$site_zip->close();
} elseif (is_dir($site_file)) {
	$site_dir = $site_file;
} else {
	echo "Couldn't find update site '$site_file'\n";
	exit(1);
}

echo "Reading site.xml...\n";
$site_xml = simplexml_load_file("$site_dir/site.xml");
$feature_jar = new ZipArchive();
foreach ($site_xml->feature as $feature) {
	if (array_key_exists('os',$feature) && $feature['os'] && !strpos($feature['os'],'linux'))
		continue;
	if (array_key_exists('arch',$feature) && $feature['arch'] && !strpos($feature['arch'],$arch))
		continue;
	if ($feature_jar->open($site_dir.'/'.$feature['url']) !== true) {
		echo "Unable to open feature jar: ".$feature['url']."\n";
		exit(1);
	}
	$feature_dir = $target_dir.'/'.substr($feature['url'],0,strrpos($feature['url'],'.'));
	echo "Extracting ".$feature['url']."...\n";
	$feature_jar->extractTo($feature_dir);
	$feature_jar->close();

	echo "Reading    $feature_dir/feature.xml...\n";
	$feature_xml = simplexml_load_file("$feature_dir/feature.xml");
	$plugin_jar = new ZipArchive();
	foreach ($feature_xml->plugin as $plugin) {
		if ($plugin['os'] && !strpos($plugin['os'],'linux'))
			continue;
		if ($plugin['arch'] && !strpos($plugin['arch'],$arch))
			continue;
		$plugin_url = 'plugins/'.$plugin['id'].'_'.$plugin['version'].'.jar';
		$plugin_dir = "$target_dir/plugins/".$plugin['id'].'_'.$plugin['version'];
		if ($plugin['unpack'] == 'true') {
			if ($plugin_jar->open("$site_dir/$plugin_url") !== true) {
				echo "Unable to open plugin jar: ".$feature['url']."\n";
				exit(1);
			}
			echo "Extracting $plugin_url => $plugin_dir\n";
			$plugin_jar->extractTo($plugin_dir);
			$plugin_jar->close();
		} else {
			echo "Copying    $plugin_url => $target_dir/$plugin_url\n";
			exec("cp -r $site_dir/$plugin_url $target_dir/$plugin_url");
		}
	}
}

?>
